@@ -306,8 +306,11 @@ class DescribeCloudMusicRequest(AbstractModel):
         """
         :param MusicId: 歌曲Id
         :type MusicId: str
-        :param MusicType: MP3-320K-FTD-P  为获取320kbps歌曲热门片段。
-MP3-320K-FTD 为获取320kbps已核验歌曲完整资源。
+        :param MusicType: 歌曲类型，可选值有：
+<li>MP3-128K-FTW：含有水印的试听资源；</li>
+<li>MP3-320K-FTD-P：320kbps歌曲热门片段；</li>
+<li>MP3-320K-FTD：320kbps已核验歌曲完整资源。</li>
+默认为：MP3-128K-FTW
         :type MusicType: str
         """
         self.MusicId = None
@@ -522,6 +525,64 @@ class DescribeItemsResponse(AbstractModel):
         
 
 
+class DescribeKTVMusicDetailRequest(AbstractModel):
+    """DescribeKTVMusicDetail请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param MusicId: 曲目 Id
+        :type MusicId: str
+        """
+        self.MusicId = None
+
+
+    def _deserialize(self, params):
+        self.MusicId = params.get("MusicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class DescribeKTVMusicDetailResponse(AbstractModel):
+    """DescribeKTVMusicDetail返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param KTVMusicBaseInfo: 歌曲基础信息
+        :type KTVMusicBaseInfo: :class:`tencentcloud.ame.v20190916.models.KTVMusicBaseInfo`
+        :param PlayToken: 播放凭证
+        :type PlayToken: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.KTVMusicBaseInfo = None
+        self.PlayToken = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("KTVMusicBaseInfo") is not None:
+            self.KTVMusicBaseInfo = KTVMusicBaseInfo()
+            self.KTVMusicBaseInfo._deserialize(params.get("KTVMusicBaseInfo"))
+        self.PlayToken = params.get("PlayToken")
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
 class DescribeLyricRequest(AbstractModel):
     """DescribeLyric请求参数结构体
 
@@ -939,6 +1000,50 @@ class Item(AbstractModel):
         
 
 
+class KTVMusicBaseInfo(AbstractModel):
+    """KTV 曲目基础信息
+
+    """
+
+    def __init__(self):
+        """
+        :param MusicId: 歌曲 Id
+        :type MusicId: str
+        :param Name: 歌曲名称
+        :type Name: str
+        :param SingerSet: 演唱者列表
+        :type SingerSet: list of str
+        :param LyricistSet: 作词者列表
+        :type LyricistSet: list of str
+        :param ComposerSet: 作曲者列表
+        :type ComposerSet: list of str
+        :param TagSet: 标签列表
+        :type TagSet: list of str
+        """
+        self.MusicId = None
+        self.Name = None
+        self.SingerSet = None
+        self.LyricistSet = None
+        self.ComposerSet = None
+        self.TagSet = None
+
+
+    def _deserialize(self, params):
+        self.MusicId = params.get("MusicId")
+        self.Name = params.get("Name")
+        self.SingerSet = params.get("SingerSet")
+        self.LyricistSet = params.get("LyricistSet")
+        self.ComposerSet = params.get("ComposerSet")
+        self.TagSet = params.get("TagSet")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
 class Lyric(AbstractModel):
     """歌词信息
 
@@ -1091,6 +1196,18 @@ class MusicDetailInfo(AbstractModel):
         :type Bpm: int
         :param Score: 商业化权益
         :type Score: float
+        :param Scene: 场景信息
+        :type Scene: list of str
+        :param Region: 应用地域
+        :type Region: list of str
+        :param AuthPeriod: 授权期限
+        :type AuthPeriod: str
+        :param Commercialization: 商业化权益
+        :type Commercialization: str
+        :param Platform: 跨平台传播权益
+        :type Platform: str
+        :param Channel: 传播渠道
+        :type Channel: str
         """
         self.MusicId = None
         self.AmeId = None
@@ -1098,6 +1215,12 @@ class MusicDetailInfo(AbstractModel):
         self.HitWords = None
         self.Bpm = None
         self.Score = None
+        self.Scene = None
+        self.Region = None
+        self.AuthPeriod = None
+        self.Commercialization = None
+        self.Platform = None
+        self.Channel = None
 
 
     def _deserialize(self, params):
@@ -1107,6 +1230,12 @@ class MusicDetailInfo(AbstractModel):
         self.HitWords = params.get("HitWords")
         self.Bpm = params.get("Bpm")
         self.Score = params.get("Score")
+        self.Scene = params.get("Scene")
+        self.Region = params.get("Region")
+        self.AuthPeriod = params.get("AuthPeriod")
+        self.Commercialization = params.get("Commercialization")
+        self.Platform = params.get("Platform")
+        self.Channel = params.get("Channel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1378,7 +1507,7 @@ reportData由两部分数据组成：
 不同的report_type对应的data数据结构不一样。
 
 详细说明请参考文档reportdata.docx：
-https://github.com/ame-demo/doc
+https://github.com/tencentyun/ame-documents
         :type ReportData: str
         """
         self.ReportData = None
@@ -1419,6 +1548,75 @@ class ReportDataResponse(AbstractModel):
         
 
 
+class SearchKTVMusicsRequest(AbstractModel):
+    """SearchKTVMusics请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param KeyWord: 搜索关键词
+        :type KeyWord: str
+        :param Offset: 分页游标
+        :type Offset: int
+        :param Limit: 分页页长
+        :type Limit: int
+        """
+        self.KeyWord = None
+        self.Offset = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.KeyWord = params.get("KeyWord")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class SearchKTVMusicsResponse(AbstractModel):
+    """SearchKTVMusics返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 总记录数
+        :type TotalCount: int
+        :param KTVMusicInfoSet: KTV 曲目列表
+        :type KTVMusicInfoSet: list of KTVMusicBaseInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.KTVMusicInfoSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("KTVMusicInfoSet") is not None:
+            self.KTVMusicInfoSet = []
+            for item in params.get("KTVMusicInfoSet"):
+                obj = KTVMusicBaseInfo()
+                obj._deserialize(item)
+                self.KTVMusicInfoSet.append(obj)
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
 class Station(AbstractModel):
     """分类内容
 
